import {getCars} from './getCars';
import {colorLegend} from './colorLegend';

import {generateReport} from './generateReport';

import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleTime,
  line,
  nest,
  curveBasis,
  scaleOrdinal,
  schemeCategory10,//pre zaoblovanie ciary
  descending
	} from 'd3' //importujeme potrebne fcie z d3
const svg=select('svg');
const width=+svg.attr('width');
const height=+svg.attr('height');


const render = data=>{
  
  const xValue=d=>d.timestamp;
  const yValue=d=>d.temperature;
  const circleRadius=7;
  const xAxisLabel='Time';
  const yAxisLabel='Temperature';
  const colorValue=d=>d.city;
  const graphTitle='A week of temperature around the world';
  const margin={top:50,bottom:60,left:90,right:250};
  const innerWidth=width-margin.left-margin.right;
  const innerHeight=height-margin.top-margin.bottom;
  
  const xScale=scaleTime() //instance of scale linear
    .domain(extent(data,xValue)) //extent vracia pole -min,max range
    .range([0,innerWidth])
     .nice();
  
 
  const g =svg.append('g')//group element
    .attr('transform',`translate(${margin.left},${margin.top})`);
  
  
  
  const yScale=scaleLinear()
  	 .domain(extent(data,yValue))
    .range([innerHeight,0])
    .nice();
  
  const colorScale= scaleOrdinal(schemeCategory10);
  
  //const xAxisTickFormat=number=>format('.3s')(number)
  //   .replace('G','B');
  
  const xAxis=axisBottom(xScale)
  		//.tickFormat(xAxisTickFormat)
      .tickSize(-innerHeight)
      .tickPadding(12);
  
  const yAxis=axisLeft(yScale)
   .tickSize(-innerWidth)
    .tickPadding(10);
  
 
  const yAxisG=g.append('g').call(yAxis);
  	//.selectAll('.domain,.tick line') //dodatocne zmazanie ciary vert. osi
   // .remove();
  
   yAxisG.append('text')//popis vodorovnej osi
  .attr('class','axis-label')//aby sme to vedeli vyselektovat pre styling
  .attr('y',-50)
  .attr('x',-innerHeight/2)
  .attr('fill','black')
  .text(yAxisLabel)
  .attr('transform',`rotate(-90)`)
  .attr('text-anchor','middle');
  
  const xAxisG= g.append('g').call(xAxis)
    .attr('transform',`translate(0,${innerHeight})`);
  xAxisG
    .select('.domain')
    .remove();
  xAxisG.append('text')//popis vodorovnej osi
  .attr('class','axis-label')//aby sme to vedeli vyselektovat pre styling
  .attr('y',60)
  .attr('x',innerWidth/2)
  .attr('fill','black')
  .text(xAxisLabel);
  
 /* // nepotrebujeme uz robit data join, staci nam append path
  g.selectAll('circle').data(data)
    .enter().append('circle')
    .attr('cy',d=>yScale(yValue(d)))
    .attr('cx',d=>xScale(xValue(d)))
    .attr('r',circleRadius)
  */
  const lineGenerator=line()
   .x(d=>xScale(xValue(d)))
   .y(d=>yScale(yValue(d)))
   .curve(curveBasis);//spline-smmothing
  
  
  //=d znamena berie input d
  const lastYValue=d=>yValue(d.values[d.values.length-1]);
  
  const nested= nest()
    .key(colorValue) //kluc podla ktoreho kuskujeme - mesta
    .entries(data) //data kt chceme rozkuskovat
     .sort((a,b)=>
    descending(lastYValue(a),lastYValue(b)));
  colorScale.domain(nested.map(d=>d.key));
  
 // console.log(nested);
  
  g.selectAll('.line-path').data(nested)
    .enter().append('path')
    .attr('class','line-path')
   .attr('d',d=>lineGenerator(d.values))
   .attr('stroke',d=>colorScale(d.key));
 // .attr('stroke','blue');
  
  g.append('text')
  .attr('y',-10)
  .attr('x',innerWidth/10)
  .attr('class','title')
  .text(graphTitle);//nadpis
  
  svg.append('g')
  .attr('transform',`translate(750,80)`)
  .call(colorLegend,{
           colorScale,
           circleRadius:15,
           spacing:40,
           textOffset:30
           });

};
 

csv('https://vizhub.com/curran/datasets/data-canvas-sense-your-city-one-week.csv')
  .then(data =>{
   data.forEach(d =>{
                d.temperature=+d.temperature; //zmena na cislo
                d.timestamp=new Date(d.timestamp);
      					
   });
    render(data);
});





